package com.dgtly.web.controller.system;

import java.util.List;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.dgtly.common.annotation.Log;
import com.dgtly.common.enums.BusinessType;
import com.dgtly.system.domain.AlertConfiguration;
import com.dgtly.system.service.IAlertConfigurationService;
import com.dgtly.common.core.controller.BaseController;
import com.dgtly.common.core.domain.AjaxResult;
import com.dgtly.common.utils.poi.ExcelUtil;
import com.dgtly.common.core.page.TableDataInfo;

/**
 * 弹框配置Controller
 * 
 * @author chenyn
 * @date 2023-06-13
 */
@Controller
@RequestMapping("/system/configuration")
public class AlertConfigurationController extends BaseController
{
    //前端代码路径
    private String prefix = "system/alertConfiguration";

    @Autowired
    private IAlertConfigurationService alertConfigurationService;

    @RequiresPermissions("system:configuration:view")
    @GetMapping()
    public String configuration()
    {
        return prefix + "/configuration";
    }

    /**
     * 查询弹框配置列表
     */
    @RequiresPermissions("system:configuration:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(AlertConfiguration alertConfiguration)
    {
        startPage();
        List<AlertConfiguration> list = alertConfigurationService.selectAlertConfigurationList(alertConfiguration);
        return getDataTable(list);
    }

    /**
     * 导出弹框配置列表
     */
    @RequiresPermissions("system:configuration:export")
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(AlertConfiguration alertConfiguration)
    {
        List<AlertConfiguration> list = alertConfigurationService.selectAlertConfigurationList(alertConfiguration);
        ExcelUtil<AlertConfiguration> util = new ExcelUtil<AlertConfiguration>(AlertConfiguration.class);
        return util.exportExcel(list, "configuration");
    }

    /**
     * 新增弹框配置
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存弹框配置
     */
    @RequiresPermissions("system:configuration:add")
    @Log(title = "弹框配置", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(AlertConfiguration alertConfiguration)
    {
        int num = alertConfigurationService.selectAlertConfigurationListFilter();
        if (alertConfiguration.getAlertStatus().equals("1")&&num==1){
            return error("弹幕通知只能有一个启动，请修改后重新添加");
        }
        return toAjax(alertConfigurationService.insertAlertConfiguration(alertConfiguration));
    }

    /**
     * 修改弹框配置
     */
    @GetMapping("/edit/{alertId}")
    public String edit(@PathVariable("alertId") Long alertId, ModelMap mmap)
    {
        AlertConfiguration alertConfiguration = alertConfigurationService.selectAlertConfigurationById(alertId);
        mmap.put("alertConfiguration", alertConfiguration);
        return prefix + "/edit";
    }

    /**
     * 修改保存弹框配置
     */
    @RequiresPermissions("system:configuration:edit")
    @Log(title = "弹框配置", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(AlertConfiguration alertConfiguration)
    {
        //没改之前的配置
        AlertConfiguration alertConfiguration1 = alertConfigurationService.selectAlertConfigurationById(alertConfiguration.getAlertId());
        //判断之前有没有
        int num = alertConfigurationService.selectAlertConfigurationListFilter();
        if(num==1){
            if (alertConfiguration1.getAlertStatus().equals("1")){
                return toAjax(alertConfigurationService.updateAlertConfiguration(alertConfiguration));
            }else {
                if (alertConfiguration.getAlertStatus().equals("1")){
                    return AjaxResult.error("列表中只能有一条日志配置启动");
                }else {
                    return toAjax(alertConfigurationService.updateAlertConfiguration(alertConfiguration));
                }
            }
        }else {
            return toAjax(alertConfigurationService.updateAlertConfiguration(alertConfiguration));
        }
    }

    /**
     * 删除弹框配置
     */
    @RequiresPermissions("system:configuration:remove")
    @Log(title = "弹框配置", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(alertConfigurationService.deleteAlertConfigurationByIds(ids));
    }
}
